==> pantsbuild.pants-2.9.0.dev3-cp39-cp39-manylinux2014_x86_64.whl: pants/backend/docker/goals/tailor.py <==
# Copyright 2021 Pants project contributors (see CONTRIBUTORS.md).
# Licensed under the Apache License, Version 2.0 (see LICENSE).

from __future__ import annotations

import os
from dataclasses import dataclass

from pants.backend.docker.target_types import DockerImageSourceField, DockerImageTarget
from pants.core.goals.tailor import (
    AllOwnedSources,
    PutativeTarget,
    PutativeTargets,
    PutativeTargetsRequest,
)
from pants.engine.fs import PathGlobs, Paths
from pants.engine.internals.selectors import Get
from pants.engine.rules import collect_rules, rule
from pants.engine.unions import UnionRule
from pants.util.logging import LogLevel


@dataclass(frozen=True)
class PutativeDockerTargetsRequest(PutativeTargetsRequest):
    pass


@rule(level=LogLevel.DEBUG, desc="Determine candidate Docker targets to create")
async def find_putative_targets(
    req: PutativeDockerTargetsRequest, all_owned_sources: AllOwnedSources
) -> PutativeTargets:
    all_dockerfiles = await Get(Paths, PathGlobs, req.search_paths.path_globs("*Dockerfile*"))
    unowned_dockerfiles = set(all_dockerfiles.files) - set(all_owned_sources)
    pts = []
    for dockerfile in sorted(unowned_dockerfiles):
        dirname, filename = os.path.split(dockerfile)
        kwargs = {}
        if filename != DockerImageSourceField.default:
            kwargs["source"] = filename
        pts.append(
            PutativeTarget.for_target_type(
                DockerImageTarget, dirname, "docker", [filename], kwargs=kwargs
            )
        )
    return PutativeTargets(pts)


def rules():
    return [
        *collect_rules(),
        UnionRule(PutativeTargetsRequest, PutativeDockerTargetsRequest),
    ]

==> pantsbuild.pants-2.13.0.dev2-cp39-cp39-manylinux2014_x86_64.whl: pants/backend/docker/goals/tailor.py <==
# Copyright 2021 Pants project contributors (see CONTRIBUTORS.md).
# Licensed under the Apache License, Version 2.0 (see LICENSE).

from __future__ import annotations

import os
from dataclasses import dataclass

from pants.backend.docker.subsystems.docker_options import DockerOptions
from pants.backend.docker.target_types import DockerImageSourceField, DockerImageTarget
from pants.core.goals.tailor import (
    AllOwnedSources,
    PutativeTarget,
    PutativeTargets,
    PutativeTargetsRequest,
)
from pants.engine.fs import PathGlobs, Paths
from pants.engine.internals.selectors import Get
from pants.engine.rules import collect_rules, rule
from pants.engine.unions import UnionRule
from pants.util.logging import LogLevel


@dataclass(frozen=True)
class PutativeDockerTargetsRequest(PutativeTargetsRequest):
    pass


@rule(level=LogLevel.DEBUG, desc="Determine candidate Docker targets to create")
async def find_putative_targets(
    req: PutativeDockerTargetsRequest, all_owned_sources: AllOwnedSources, docker: DockerOptions
) -> PutativeTargets:
    if not docker.tailor:
        return PutativeTargets()

    all_dockerfiles = await Get(Paths, PathGlobs, req.search_paths.path_globs("*Dockerfile*"))
    unowned_dockerfiles = set(all_dockerfiles.files) - set(all_owned_sources)
    pts = []
    for dockerfile in sorted(unowned_dockerfiles):
        dirname, filename = os.path.split(dockerfile)
        kwargs = {} if filename == DockerImageSourceField.default else {"source": filename}
        pts.append(
            PutativeTarget.for_target_type(
                DockerImageTarget,
                path=dirname,
                name="docker",
                triggering_sources=[filename],
                kwargs=kwargs,
            )
        )
    return PutativeTargets(pts)


def rules():
    return [
        *collect_rules(),
        UnionRule(PutativeTargetsRequest, PutativeDockerTargetsRequest),
    ]
